//
// XMM Science Analysis System
//
// Giuseppe Vacanti (cosine science & computing) 
// February 2002
//
#ifndef EPICPROCSTATE_H
#define EPICPROCSTATE_H

#include<string>
#include<vector>
#include<map>
#include<Xmm.h>
#include<Odf.h>
#include<ParameterInfo.h>
#include<Proc.h>

struct EpicProcState {

  EpicProcState(unsigned nccds,
		const XmmInstrument& inst,
		Xmm::DataMode df)
    :
    number_of_ccds(nccds),
    inst(inst),
    default_mode(df),
    mypars(*Info::Task::current()->parameters()),
    proc(Proc("./"))
  {
    has_filterexpression = false;
    filter_expression = "";
    has_atthkgenset = false;
    has_observationlevelgti = false;
    has_hkgti = false;
    generic_flag = false;
    destructive_filter = false;
  }
    
  const unsigned number_of_ccds;
  const XmmInstrument& inst;
  const Xmm::DataMode default_mode;
  ParameterInfo& mypars;
  Proc proc;

  std::map<std::string, Xmm::DataMode> allowed_modes;
  std::vector<std::string> observation_gtis;
  std::vector<std::string> exposure_gtis;
  std::vector<std::string> ccd_gtis;
  std::vector<std::string> exposure_evlists;
  //AI: Temporary mos event list
  std::vector<std::string> exposure_tempEvlists;
  std::vector<std::string> badpix_evlists;
  //AI: epframes output filenames
  std::vector<std::string> epframes_Evlists;
  std::string filterexpression;
  std::vector<Proc::ScienceExposure> exposures;
  std::vector<Xmm::DataMode> datamodes;
  std::vector<Ccd> ccds;

  //AI: Vector to store the FOV of CCD specific event files
  std::vector<double> inFOVarea;
  double areaCcd;
  bool hasValidGTI;

  bool has_filterexpression;
  std::string filter_expression;
  std::string post_selection_expression;
  //AI: Expression used during the Intermediate results
  std::string merge_selection_expression;
  bool has_atthkgenset;
  bool has_observationlevelgti;
  bool has_hkgti;
  bool has_badpixset;
  bool generic_flag;
  bool destructive_filter;

  typedef  std::vector<Proc::ScienceExposure>::iterator EI;
  typedef std::list<const OdfSet*>::const_iterator LI;

};

#endif
